@@ -70,7 +70,7 @@ void KPluginSelector::Private::updateDependencies(PluginEntry *pluginEntry, bool
     if (added) {
         QStringList dependencyList = pluginEntry->pluginInfo.dependencies();
 
-        if (!dependencyList.count()) {
+        if (dependencyList.isEmpty()) {
             return;
         }
 
@@ -222,7 +222,7 @@ void KPluginSelector::Private::DependenciesWidget::showDependencyDetails()
 
 void KPluginSelector::Private::DependenciesWidget::updateDetails()
 {
-    if (!dependencyMap.count()) {
+    if (dependencyMap.isEmpty()) {
         setVisible(false);
         return;
     }
@@ -258,7 +258,7 @@ KPluginSelector::KPluginSelector(QWidget *parent)
 
     d->lineEdit = new QLineEdit(this);
     d->lineEdit->setClearButtonEnabled(true);
-    d->lineEdit->setPlaceholderText(i18n("Search Plugins"));
+    d->lineEdit->setPlaceholderText(i18n("Search..."));
     d->listView = new KCategorizedView(this);
     d->categoryDrawer = new KCategoryDrawer(d->listView);
     d->listView->setVerticalScrollMode(QListView::ScrollPerPixel);
@@ -414,6 +414,26 @@ QStringList KPluginSelector::configurationArguments() const
     return d->kcmArguments;
 }
 
+void KPluginSelector::showConfiguration(const QString& componentName)
+{
+    QModelIndex idx;
+    for (int i = 0, c = d->proxyModel->rowCount(); i<c; ++i) {
+        const auto currentIndex = d->proxyModel->index(i, 0);
+        const auto entry = currentIndex.data(KPluginSelector::Private::PluginEntryRole).value<PluginEntry *>();
+        if (entry->pluginInfo.pluginName() == componentName) {
+            idx = currentIndex;
+            break;
+        }
+    }
+
+    if (idx.isValid()) {
+        auto delegate = static_cast<KPluginSelector::Private::PluginDelegate*>(d->listView->itemDelegate());
+        delegate->configure(idx);
+    } else {
+        qWarning() << "Could not find plugin" << componentName;
+    }
+}
+
 KPluginSelector::Private::PluginModel::PluginModel(KPluginSelector::Private *pluginSelector_d, QObject *parent)
     : QAbstractListModel(parent)
     , pluginSelector_d(pluginSelector_d)
@@ -457,7 +477,7 @@ void KPluginSelector::Private::PluginModel::addPlugins(const QList<KPluginInfo>
         }
     }
 
-    if (listToAdd.count()) {
+    if (!listToAdd.isEmpty()) {
         beginInsertRows(QModelIndex(), pluginEntryList.count(), pluginEntryList.count() + listToAdd.count() - 1);
         pluginEntryList << listToAdd;
         endInsertRows();
@@ -687,10 +707,12 @@ QList<QWidget *> KPluginSelector::Private::PluginDelegate::createItemWidgets(con
 
     QPushButton *aboutPushButton = new QPushButton;
     aboutPushButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
+    aboutPushButton->setToolTip(i18n("About"));
     connect(aboutPushButton, &QAbstractButton::clicked, this, &PluginDelegate::slotAboutClicked);
 
     QPushButton *configurePushButton = new QPushButton;
     configurePushButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    configurePushButton->setToolTip(i18n("Configure"));
     connect(configurePushButton, &QAbstractButton::clicked, this, &PluginDelegate::slotConfigureClicked);
 
     setBlockedEventTypes(enabledCheckBox, QList<QEvent::Type>() << QEvent::MouseButtonPress
@@ -794,7 +816,11 @@ void KPluginSelector::Private::PluginDelegate::slotAboutClicked()
 
 void KPluginSelector::Private::PluginDelegate::slotConfigureClicked()
 {
-    const QModelIndex index = focusedIndex();
+    configure(focusedIndex());
+}
+
+void KPluginSelector::Private::PluginDelegate::configure(const QModelIndex& index)
+{
     const QAbstractItemModel *model = index.model();
 
     PluginEntry *pluginEntry = model->data(index, PluginEntryRole).value<PluginEntry *>();
@@ -848,7 +874,7 @@ void KPluginSelector::Private::PluginDelegate::slotConfigureClicked()
     }
 
     // it could happen that we had services to show, but none of them were real modules.
-    if (moduleProxyList.count()) {
+    if (!moduleProxyList.isEmpty()) {
         QVBoxLayout *layout = new QVBoxLayout;
         layout->addWidget(mainWidget);
         const int marginHint = configDialog.style()->pixelMetric(QStyle::PM_DefaultChildMargin);
